<?php




require_once GREEN_ZONE_DIR . 'Utils/StringUtils.php';



class Angle
{
  // PUBLIC

  public function __construct( Angle $rhs = null )
  {
    $this->radians = 0.0;

    if( $rhs != null )
      $this->Copy( $rhs );
  }
  public function Copy( Angle $rhs )
  {
    $this->radians = $rhs->ToRadians();
  }
  
  ////////////////////////////////////////////////
  // RADIANS

  //! Convert this angle to radians
  public function ToRadians() { return $this->radians; }
  
  //! Set this angle using the radians given
  public function FromRadians( $s_radians ) { $this->radians = $s_radians; }
  
  //! Create a new angle using the radians given
  public static function ConvertRadians( $s_radians )
  {
    $angle = new Angle();
    $angle->FromRadians( $s_radians );
    return $angle;
  }
  
  ////////////////////////////////////////////////
  // DEGREES

  //! Convert this angle to degrees
  public function ToDegrees() { return ($this->radians / M_PI * 180.0); }
  
  //! Set this angle using the degrees given
  public function FromDegrees( $s_degrees ) { $this->radians = $s_degrees / 180.0 * M_PI; }
  
  //! Create a new angle using the degrees given.
  public static function ConvertDegrees( $s_degrees )
  {
    $angle = new Angle();
    $angle->FromDegrees( $s_degrees );
    return $angle;
  }
  
  ////////////////////////////////////////////////
  // HOURS MINS SECONDS
  
  //! Convert this angle to hours,mins,seconds
  public function ToHMS( &$hours, &$mins, &$secs )
  {
    $degrees = $this->ToDegrees();
    $hours = floor( ($degrees * 24.0) / 360.0);
    $hours_remainder = (( $degrees * 24.0) / 360.0 ) - $hours;
    $mins = floor( $hours_remainder * 60.0 );
    $mins_remainder = ($hours_remainder * 60.0) - $mins;
    $secs = $mins_remainder * 60;
  }
  
  //! Set this angle using the hours,mins,seconds given
  public function FromHMS( $s_hours, $s_mins, $s_secs )
  {
    $this->FromDegrees( $s_hours * 15.0 + $s_mins * 0.25 + $s_secs * 0.25 / 60.0 );
  }

  //! Create a new Angle using the hours,mins,seconds given.
  public static function ConvertHMS( $s_hours, $s_mins, $s_secs )
  {
    $angle = new Angle();
    $angle->FromHMS( $s_hours, $s_mins, $s_secs );
    return $angle;
  }

  ////////////////////////////////////////////////
  // HMS STRINGS

  //! Set this angle using the hms string given
  public function FromHMSString( $s_hms )
  {
    $hours = strword( $s_hms, 0, ':' );
    $mins = strword( $s_hms, 1, ':' );
    $secs = strword( $s_hms, 2, ':' );

    $this->FromHMS( $hours, $mins, $secs );
  }
  
  //! Convert this angle to a hms string
  public function ToHMSString()
  {
    $hours = 0;
    $mins = 0;
    $secs = 0;
    $this->ToHMS( $hours, $mins, $secs );
    
    return sprintf("%02d:%02d:%02d", $hours, $mins, $secs );
  }
  
  //! Create a new Angle using the hms string given.
  public static function ConvertHMSString( $s_hms_string )
  {
    $angle = new Angle();
    $angle->FromHMSString( $s_hms_string );
    return $angle;
  }
  
  ////////////////////////////////////////////////
  // DEGREES MINUTES SECONDS

  //! Convert this anglel to degrees,minutes,seconds
  public function ToDMS( &$degrees, &$mins, &$secs )
  {
    $degrees = $this->ToDegrees();
    $remainder = $degrees - floor($degrees);
    $mins = floor( $remainder * 60.0 );
    $remainder = ($remainder * 60.0) - $mins;
    $secs = $remainder * 60.0;
    $degrees = floor($degrees);
  }
  
  //! Set this angle using the degrees,mins,seconds given
  public function FromDMS( $s_degrees, $s_mins, $s_secs )
  {
    $degrees = $s_degrees;
    $degrees += $s_mins / 60.0;
    $degrees += $s_secs / 3600.0;
    $this->FromDegrees( $degrees );
  }

  //! Create a new angle using the degrees,minutes,seconds given
  public static function ConvertDMS( $s_degrees, $s_mins, $s_secs )
  {
    $angle = new Angle();
    $angle->FromDMS( $s_degrees, $s_mins, $s_secs );
    return $angle;
  }

  ////////////////////////////////////////////////
  // DMS STRING

  //! Convert this angle to a DMS string
  public function ToDMSString()
  {
    $degrees;
    $mins;
    $secs;
    $this->ToDMS( $degrees, $mins, $secs );

    return sprintf("%02d:%02d:%06.3f", $degrees, $mins, $secs );
  }
  
  //! Set this angle using the DMS string given
  public function FromDMSString( $dms_string )
  {
    $degrees = strword( $dms_string, 0, ':' );
    $mins = strword( $dms_string, 1, ':' );
    $secs = strword( $dms_string, 2, ':' );
    $this->FromDMS( $degrees, $mins, $secs );
  }
  
  //! Create a new angle using the dms string given
  public static function ConvertDMSString( $s_dms_string )
  {
    $angle = new Angle();
    $angle->FromDMSString( $s_dms_string );
    return $angle;
  }

  // PRIVATE

  private $radians;

};

?>