<?php



require_once 'config.php';
require_once GREEN_ZONE_DIR . 'Utils/StringUtils.php';
require_once 'Classes/Astro/Angle.php';



/**
 * This class represents a coordinate in the sky, as right ascention and declanation.
 **/

class SkyCoord
{
  public function __construct( SkyCoord $rhs  = null )
  {
    $this->ra = new Angle();
    $this->dec = new Angle();

    if( $rhs != null )
      $this->Copy( $rhs );
  }
  public function Copy( SkyCoord $rhs )
  {
    $this->ra = new Angle( $rhs->GetRA() );
    $this->dec = new Angle( $rhs->GetDEC() );
  }
  
  public function GetRA() { return $this->ra; }
  public function GetDEC() { return $this->dec; }
  
  public function SetRA( $s_ra ) { $this->ra = $s_ra; }
  public function SetDEC( $s_dec ) { $this->dec = $s_dec; }

  public function GetRAHour() { return strword( $this->ra->ToHMSString(), 0, ':' ); }
  public function GetRAMin() { return strword( $this->ra->ToHMSString(), 1, ':' ); }
  public function GetRASec() { return strword( $this->ra->ToHMSString(), 2, ':' ); }

  public function GetDECDeg() { return strword( $this->dec->ToDMSString(), 0, ':' ); }
  public function GetDECMin() { return strword( $this->dec->ToDMSString(), 1, ':' ); }
  public function GetDECSec() { return strword( $this->dec->ToDMSString(), 2, ':' ); }

  public function FromHMSDMSString( $coord_string )
  {
    $ra = strword( $coord_string, 0 );
    $dec = strword( $coord_string, 1 );

    $this->ra->FromHMSString( $ra );
    $this->dec->FromDMSString( $dec );
  }

  public function ToHMSDMSString() 
  {
    if( $this->ra == null || $this->dec == null )
      return '';

    return $this->ra->ToHMSString() . ' ' . $this->dec->ToDMSString();
  }
  
  
  ////////////////////////////////////////////////
  // RA DEC

  //! Convert these coordinates to ra and dec
  public function ToRADEC( &$g_ra, &$g_dec )
  {
    $g_ra = $this->GetRA();
    $g_dec = $this->GetDEC();
  }
  
  //! Set these coordinates using the ra and dec given
  public function FromRADEC( $s_ra, $s_dec )
  {
    $this->SetRA( $s_ra );
    $this->SetDEC( $s_dec );
  }
  
  //! Create a new sky coordinate object using the ra and dec given
  public static function ConvertRADEC( $s_ra, $s_dec )
  {
    $coord = new SkyCoord();
    $coord->FromRADEC( $s_ra, $s_dec );
    return $coord;
  }
  
  private $ra;
  private $dec;
};





?>