<?php



require_once 'Classes/Model/Observation.php';



/**
 * @class ObservationSet
 *
 * This class represents an observation and a set of associated calibrations. These
 * calibrations will be within X minutes of the observation
 **/
class ObservationSet
{
  // PUBLIC

  public function __construct( ObservationSet $rhs = null )
  {
    $this->observation = null;
    $this->calibrations = null;
    $this->observation_data = new ObservationData();

    if( $rhs != null )
      $this->Copy( $rhs );
  }
  public function Copy( ObservationSet $rhs )
  {
    $this->observation = new Observation( $rhs->GetObservation() );

    $this->calibrations = Array();
    foreach( $rhs->calibrations as $next_cal )
      $this->calibrations[] = new Calibration( $next_cal );

    $this->observation_data = new ObservationData( $rhs->observation_data );
  }

  public function SetObservation( $s_observation ) { $this->observation = $s_observation; }
  public function GetObservation() { return $this->observation; }

  public function SetCalibrations( $s_calibrations ) { $this->calibrations = $s_calibrations; }
  public function GetCalibrations() { return $this->calibrations; }
  
  //! Get the adjusted filename, this will include scrunching parameters if set
  public function GetFilename()
  {
    $filename = $this->GetObservation()->GetFile()->GetFilename();

    if( $this->GetScrunchingParameters() != null )
    {
      $filename = AddPreExtension( $filename,
				  $this->GetScrunchingParameters()->GetTextDescription() );
    }
    
    return $filename;
  }
  
  public function SetScrunchingParameters( ScrunchingParameters $s_scrunching_parameters ) 
  {
    $this->observation_data->SetScrunchingParameters( $s_scrunching_parameters );
  }
  
  public function GetScrunchingParameters() { return $this->observation_data->GetScrunchingParameters(); }
  
  //! This function creates the observation_data object and sets it up
  public function SetupObservationData()
  {
    $this->observation_data->SetPath( $this->observation->GetFile() );
    $this->observation_data->SetNBin( $this->observation->GetNBin() );
    $this->observation_data->SetNPol( $this->observation->GetNPol() );
    $this->observation_data->SetNChan( $this->observation->GetNChan() );
    $this->observation_data->SetNSub( $this->observation->GetNSub() );
  }
  
  public function EstimateDownloadableSize()
  {
    $dl_size = $this->observation_data->EstimateDownloadableSize();
    foreach( $this->calibrations as $next_cal )
    {
      $dl_size += $next_cal->GetFile()->GetFileSize();
    }

    return $dl_size;
  }

  // PRIVATE

  private $observation;
  private $calibrations;
  private $observation_data;
};

