<?php



require_once GREEN_ZONE_DIR . 'Forms/GZ_BaseForm.php';
require_once 'Classes/General/UserData.php';
require_once 'Classes/General/DateRange.php';
require_once 'Classes/Astro/Band.php';
require_once 'Classes/Astro/MJD.php';
require_once 'Classes/Model/Observation.php';
require_once 'Classes/Model/ObsSetParameters.php';
require_once 'Classes/Queries/DateRangeQuery.php';
require_once 'Classes/Pulsar/PulsarCatalog.php';




class QueryForm extends GZ_BaseForm
{
  // PUBLIC

  public function __construct( $set_gz )
  {
    global $_SESSION;

    parent::__construct( $set_gz );

    if( isset( $_SESSION['last_query'] ) )
	$this->parameters = $_SESSION['last_query'];
    else
      $this->parameters = new ObsSetParameters();
  }

  public function Display()
  {
    global $_SERVER;

    $smarty = $this->gz->CreateSmarty();

    $self = $_SERVER['PHP_SELF'];
    $self = '';
    $this->gz->smarty_assign( $smarty, 'self', $self );

    $this->gz->smarty_assign( $smarty, 'parameters', $this->parameters );
    $this->gz->smarty_assign( $smarty, 'coordinates', $this->parameters->GetCoordinates() );
    $this->gz->smarty_assign( $smarty, 'cals_window', $this->parameters->GetCalsWindow() );

    $dates_query = new DateRangeQuery();
    $full_date_range = $dates_query->Execute( $this->gz );
    
    $from_date = $this->parameters->GetDateRange()->GetFromDate();
    $to_date = $this->parameters->GetDateRange()->GetToDate();
    if( $from_date->IsUnset() )
      $from_date = $full_date_range->GetFromDate();
    if( $to_date->IsUnset() )
      $to_date = $full_date_range->GetToDate();
    
    $this->gz->smarty_assign( $smarty, 'from_date',  $from_date );
    $this->gz->smarty_assign( $smarty, 'to_date', $to_date );

    $this->gz->smarty_assign( $smarty, 'from_date_limit', $full_date_range->GetFromDate() );
    $this->gz->smarty_assign( $smarty, 'to_date_limit', $full_date_range->GetToDate() );
    
    $known_years = Array();
    for( $y = $full_date_range->GetFromDate()->GetYear(); $y < $full_date_range->GetToDate()->GetYear() + 1; $y ++ )
      $known_years[] = $y;
    $this->gz->smarty_assign( $smarty, 'known_years', $known_years );

    $this->gz->smarty_assign( $smarty, 'days_in_month', Date::$days_in_month );
    $this->gz->smarty_assign( $smarty, 'months_in_year', Date::$months_in_year );

    $this->gz->smarty_assign( $smarty, 'valid_bands', Band::$valid_bands );
    $this->gz->smarty_assign( $smarty, 'bands', $this->parameters->GetBands() );
    $this->gz->smarty_assign( $smarty, 'valid_data_types', Observation::$valid_data_types );

    $smarty->Display( 'QueryForm.tpl' );
  }

  public function ProcessActions()
  {
    if( $this->ActionIs( 'ConeQuery' ) )
    {
      $this->parameters->ReadForm( $this->gz->_POST );
      if( $this->parameters->AreValid() )
	return 'QueryResultsForm';
    }
    return '';
  }

  // PRIVATE

  private $parameters;
};



?>